@@ -1,7 +1,7 @@
 use std::fs::File;
 use std::io::{self, prelude::*, BufReader};
 
-fn is_inside_docker(path: &str) -> Result<bool, io::Error> {
+fn run(path: &str) -> Result<bool, io::Error> {
     let file = File::open(path)?;
     let reader = BufReader::new(file);
 
@@ -14,15 +14,15 @@ fn is_inside_docker(path: &str) -> Result<bool, io::Error> {
     Ok(false)
 }
 
-pub fn run() -> Result<bool, io::Error> {
-    is_inside_docker("/proc/1/cgroup")
+pub fn is_inside_docker() -> Result<bool, io::Error> {
+    run("/proc/1/cgroup")
 }
 
 #[test]
 fn test_detects_host_when_typical() {
     let expected = false;
 
-    let actual = is_inside_docker("test/proc_1_cgroup.host").unwrap();
+    let actual = run("test/proc_1_cgroup.host").unwrap();
 
     assert_eq!(expected, actual);
 }
@@ -31,7 +31,7 @@ fn test_detects_host_when_typical() {
 fn test_detects_docker_when_typical() {
     let expected = true;
 
-    let actual = is_inside_docker("test/proc_1_cgroup.docker").unwrap();
+    let actual = run("test/proc_1_cgroup.docker").unwrap();
 
     assert_eq!(expected, actual);
 }
